Introduction
============

This package contains various visual components for Plone, such as viewlets
and general views.

Compatibility
-------------

- the 2.2.x series is for use in Plone 4.2
- the 2.3.x series is for use in Plone 4.3 (versions below 2.3.2 may also work with Plone 4.2)
- the 2.5.x series is for use in Plone 5.0
- the 2.8.x series is for use in Plone 5.1
- the 3.4.x series is for use in Plone 5.2
- the 4.x  series is for use in Plone 6 (the current master/main branch)

Using other combinations *might* work, but you may find getting support for that harder.

If you are using Plone < 4.3.5 and you are using dexterity items and plone.app.contenttypes, you might want to pin the latest 2.3.x version of this package.
